@@ -40,10 +40,8 @@ indicator_metadata <- function(IndicatorID = NULL,
         set_config(config(ssl_verifypeer = 0L))
         types <- cols(`Indicator ID` = "i",
                       Indicator = "c",
-                      `Indicator full name` = "c",
                       `Definition` = "c",
                       `Rationale` = "c",
-                      `Policy` = "c",
                       `Data source` = "c",
                       `Indicator production` = "c",
                       `Indicator source` = "c",
